import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface BranchProtectionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#branch BranchProtection#branch}.
     *
     * @stability stable
     */
    readonly branch: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#enforce_admins BranchProtection#enforce_admins}.
     *
     * @stability stable
     */
    readonly enforceAdmins?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#repository BranchProtection#repository}.
     *
     * @stability stable
     */
    readonly repository: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#require_signed_commits BranchProtection#require_signed_commits}.
     *
     * @stability stable
     */
    readonly requireSignedCommits?: boolean;
    /**
     * required_pull_request_reviews block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#required_pull_request_reviews BranchProtection#required_pull_request_reviews}
     *
     * @stability stable
     */
    readonly requiredPullRequestReviews?: BranchProtectionRequiredPullRequestReviews[];
    /**
     * required_status_checks block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#required_status_checks BranchProtection#required_status_checks}
     *
     * @stability stable
     */
    readonly requiredStatusChecks?: BranchProtectionRequiredStatusChecks[];
    /**
     * restrictions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#restrictions BranchProtection#restrictions}
     *
     * @stability stable
     */
    readonly restrictions?: BranchProtectionRestrictions[];
}
/**
 * @stability stable
 */
export interface BranchProtectionRequiredPullRequestReviews {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#dismiss_stale_reviews BranchProtection#dismiss_stale_reviews}.
     *
     * @stability stable
     */
    readonly dismissStaleReviews?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#dismissal_teams BranchProtection#dismissal_teams}.
     *
     * @stability stable
     */
    readonly dismissalTeams?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#dismissal_users BranchProtection#dismissal_users}.
     *
     * @stability stable
     */
    readonly dismissalUsers?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#include_admins BranchProtection#include_admins}.
     *
     * @stability stable
     */
    readonly includeAdmins?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#require_code_owner_reviews BranchProtection#require_code_owner_reviews}.
     *
     * @stability stable
     */
    readonly requireCodeOwnerReviews?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#required_approving_review_count BranchProtection#required_approving_review_count}.
     *
     * @stability stable
     */
    readonly requiredApprovingReviewCount?: number;
}
/**
 * @stability stable
 */
export interface BranchProtectionRequiredStatusChecks {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#contexts BranchProtection#contexts}.
     *
     * @stability stable
     */
    readonly contexts?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#include_admins BranchProtection#include_admins}.
     *
     * @stability stable
     */
    readonly includeAdmins?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#strict BranchProtection#strict}.
     *
     * @stability stable
     */
    readonly strict?: boolean;
}
/**
 * @stability stable
 */
export interface BranchProtectionRestrictions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#apps BranchProtection#apps}.
     *
     * @stability stable
     */
    readonly apps?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#teams BranchProtection#teams}.
     *
     * @stability stable
     */
    readonly teams?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html#users BranchProtection#users}.
     *
     * @stability stable
     */
    readonly users?: string[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html github_branch_protection}.
 *
 * @stability stable
 */
export declare class BranchProtection extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/github/r/branch_protection.html github_branch_protection} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: BranchProtectionConfig);
    private _branch;
    /**
     * @stability stable
     */
    get branch(): string;
    /**
     * @stability stable
     */
    set branch(value: string);
    /**
     * @stability stable
     */
    get branchInput(): string;
    private _enforceAdmins?;
    /**
     * @stability stable
     */
    get enforceAdmins(): boolean;
    /**
     * @stability stable
     */
    set enforceAdmins(value: boolean);
    /**
     * @stability stable
     */
    resetEnforceAdmins(): void;
    /**
     * @stability stable
     */
    get enforceAdminsInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _repository;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    get repositoryInput(): string;
    private _requireSignedCommits?;
    /**
     * @stability stable
     */
    get requireSignedCommits(): boolean;
    /**
     * @stability stable
     */
    set requireSignedCommits(value: boolean);
    /**
     * @stability stable
     */
    resetRequireSignedCommits(): void;
    /**
     * @stability stable
     */
    get requireSignedCommitsInput(): boolean | undefined;
    private _requiredPullRequestReviews?;
    /**
     * @stability stable
     */
    get requiredPullRequestReviews(): BranchProtectionRequiredPullRequestReviews[];
    /**
     * @stability stable
     */
    set requiredPullRequestReviews(value: BranchProtectionRequiredPullRequestReviews[]);
    /**
     * @stability stable
     */
    resetRequiredPullRequestReviews(): void;
    /**
     * @stability stable
     */
    get requiredPullRequestReviewsInput(): BranchProtectionRequiredPullRequestReviews[] | undefined;
    private _requiredStatusChecks?;
    /**
     * @stability stable
     */
    get requiredStatusChecks(): BranchProtectionRequiredStatusChecks[];
    /**
     * @stability stable
     */
    set requiredStatusChecks(value: BranchProtectionRequiredStatusChecks[]);
    /**
     * @stability stable
     */
    resetRequiredStatusChecks(): void;
    /**
     * @stability stable
     */
    get requiredStatusChecksInput(): BranchProtectionRequiredStatusChecks[] | undefined;
    private _restrictions?;
    /**
     * @stability stable
     */
    get restrictions(): BranchProtectionRestrictions[];
    /**
     * @stability stable
     */
    set restrictions(value: BranchProtectionRestrictions[]);
    /**
     * @stability stable
     */
    resetRestrictions(): void;
    /**
     * @stability stable
     */
    get restrictionsInput(): BranchProtectionRestrictions[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
